@@ -1,5 +1,7 @@
 from django.core.management import BaseCommand
 
+from mentions.tasks.scheduling import handle_pending_webmentions
+
 PENDING_TYPE_ALL = "all"
 PENDING_TYPE_INCOMING = "incoming"
 PENDING_TYPE_OUTGOING = "outgoing"
@@ -23,4 +25,4 @@ class Command(BaseCommand):
             incoming = True
             outgoing = True
 
-        # handle_pending_webmentions(incoming=incoming, outgoing=outgoing)
+        handle_pending_webmentions(incoming=incoming, outgoing=outgoing)
