@@ -3,7 +3,6 @@ from django.urls import path, re_path
 from mentions.views import view_names
 from mentions.views.retrieve_mentions import GetMentionsView
 from mentions.views.submit_mentions import WebmentionView
-from tests.views import TemplateTagTestView
 
 """
 /webmention/
@@ -22,9 +21,4 @@ urlpatterns = [
         GetMentionsView.as_view(),
         name=view_names.webmention_api_get_for_object,
     ),
-    path(
-        "templatetagstest",
-        TemplateTagTestView.as_view(),
-        name="test-template-tags",
-    ),
 ]
